class OrderTest extends grails.util.WebTest {

    // Unlike unit tests, functional tests are often sequence dependent.
    // Specify that sequence here.
    void suite() {
        // add tests for more operations here
        testIndex()
        testGoSearch()
        testSearchByNoConditionAndNoData()
        testSearchByNoConditionAndOneData()
        testSearchByNoConditionAndTwoData()
        testSearchByTitleMatch()
        testSearchByTitleNotMatch()
        testSearchByAuthorMatch()
        testSearchByAuthorNoMatch()
        testSearchByIsbn13Match()
        testSearchByIsbn13NoMatch()
        testSearchByPublisherMatch()
        testSearchByPublisherNoMatch()
        testSearchByTitleAndAuthorAndIsbn13AndPublisherMatch()
        testSearchByTitleAndAuthorAndIsbn13AndPublisherNoMatch()
        testSearchFlowSearchToDetail()
        testSearchFlowSearchToToCart()
        testSearchFlowDisplayDetailToSearch()
        testSearchFlowDisplayDetailToToCart()
        testSearchFlowDisplayDetailToToCartTwice()
        testSearchFlowDisplayDetailToToCartTwo()
        testGoCart()
        testCartFlowShowCartToEditCart()
        testCartFlowEditCartToSubmit()
        testCartFlowEditCartToSubmitOther0()
        testCartFlowEditCartToCancel()
        testCartFlowShowCartToCreditCartConfirm()
        testCreditFlowCreditToNext()
        testCreditFlowCreditAccountConfirmToNext()
        testCreditFlowCreditAccountConfirmToBack()
        testCreditFlowCreditFinalConfirmToNext()
        testCreditFlowCreditFinalConfirmToBack()
        testCreditFlowCreditCompleteToFinish()
    }

    def testIndex() {
        webtest('index') {
            invoke(url: 'order')
        }
    }

    void testGoSearch() {
        webtest('メニューから「検索」') {
            invoke(url: 'order')
            clickLink(label: '検索')
            verifyText(text: 'タイトル')
            verifyText(text: '著者')
            verifyText(text: 'ISBN13')
            verifyText(text: '出版社')
        }
    }

    void testSearchByNoConditionAndNoData() {
        webtest('検索画面で条件を入力せずに「検索」ボタンを押下。マッチする書籍はなし。') {
            invoke(url: 'order')
            clickButton(label: '検索')
            verifyText(text: '検索条件に合う書籍は見つかりませんでした。')
        }
    }

    void testSearchByNoConditionAndOneData() {
        webtest('検索画面で条件を入力せずに「検索」ボタンを押下。マッチする書籍が 1 冊あり。') {

            group(description:'出版社を登録。') {
                invoke(url: 'publisher/create')
                setInputField(name: 'name', value: '翔泳社')
                clickButton(label: 'Create')
            }

            group(description:'書籍を登録。') {
                invoke(url: 'book/create')
                setInputField(name: 'title', value: 'オブジェクト指向入門 第 2 版 原則・コンセプト')
                setInputField(name: 'author', value: 'Bertrand Meyer')
                setInputField(name: 'price', value: '7560')
                setSelectField(name: 'releaseDate_day', value: '10')
                setSelectField(name: 'releaseDate_month', value: '1')
                setSelectField(name: 'releaseDate_year', value: '2007')
                setSelectField(name: 'releaseDate_hour', value: '00')
                setSelectField(name: 'releaseDate_minute', value: '00')
                setInputField(name: 'isbn13', value: '9784798111117')
                setSelectField(name: 'publisher.id', value: '1')
                clickButton(label: 'Create')
            }

            invoke(url: 'order')
            clickButton(label: '検索')
            verifyText(text: 'オブジェクト指向入門 第 2 版 原則・コンセプト')
        }
    }

    void testSearchByNoConditionAndTwoData() {
        webtest('検索画面で条件を入力せずに「検索」ボタンを押下。マッチする書籍が 2 冊あり。') {

            group(description:'書籍を登録。') {
                invoke(url: 'book/create')
                setInputField(name: 'title', value: 'UML モデリングのエッセンス 第 3 版 標準オブジェクトモデリング言語入門')
                setInputField(name: 'author', value: 'Martin Fowler')
                setInputField(name: 'price', value: '2520')
                setSelectField(name: 'releaseDate_day', value: '10')
                setSelectField(name: 'releaseDate_month', value: '6')
                setSelectField(name: 'releaseDate_year', value: '2005')
                setSelectField(name: 'releaseDate_hour', value: '00')
                setSelectField(name: 'releaseDate_minute', value: '00')
                setInputField(name: 'isbn13', value: '9784798107950')
                setSelectField(name: 'publisher.id', value: '1')
                clickButton (label: 'Create')
            }

            invoke(url: 'order')
            clickButton(label: '検索')
            verifyText(text: 'オブジェクト指向入門 第 2 版 原則・コンセプト')
            verifyText(text: 'UML モデリングのエッセンス 第 3 版 標準オブジェクトモデリング言語入門')
        }
    }

    void testSearchByTitleMatch() {
        webtest('タイトルを条件に書籍を検索。マッチする書籍が 1 冊あり。') {
            invoke(url: 'order')
            setInputField(name: 'title', value: 'オブジェクト指向入門')
            clickButton(label: '検索')
            verifyText(text: 'オブジェクト指向入門 第 2 版 原則・コンセプト')
        }
    }

    void testSearchByTitleNotMatch() {
        webtest('タイトルを条件に書籍を検索。マッチする書籍はなし。') {
            invoke(url: 'order')
            setInputField(name: 'title', value: 'アスペクト指向入門')
            clickButton(label: '検索')
            verifyText(text: '検索条件に合う書籍は見つかりませんでした。')
        }
    }

    void testSearchByAuthorMatch() {
        webtest('著者を条件に書籍を検索。マッチする書籍が 1 冊あり。') {
            invoke(url: 'order')
            setInputField(name: 'author', value: 'Meyer')
            clickButton(label: '検索')
            verifyText(text: 'オブジェクト指向入門 第 2 版 原則・コンセプト')
        }
    }

    void testSearchByAuthorNoMatch() {
        webtest('著者を条件に書籍を検索。マッチする書籍はなし。') {
            invoke(url: 'order')
            setInputField(name: 'author', value: 'Stevens')
            clickButton(label: '検索')
            verifyText(text: '検索条件に合う書籍は見つかりませんでした。')
        }
    }

    void testSearchByIsbn13Match() {
        webtest('ISBN13 を条件に書籍を検索。マッチする書籍が 1 冊あり。') {
            invoke(url: 'order')
            setInputField(name: 'isbn13', value: '9784798107950')
            clickButton(label: '検索')
            verifyText(text: 'UML モデリングのエッセンス 第 3 版 標準オブジェクトモデリング言語入門')
        }
    }

    void testSearchByIsbn13NoMatch() {
        webtest('ISBN13 を条件に書籍を検索。マッチする書籍はなし。') {
            invoke(url: 'order')
            setInputField(name: 'isbn13', value: '9784798107951')
            clickButton(label: '検索')
            verifyText(text: '検索条件に合う書籍は見つかりませんでした。')
        }
    }

    void testSearchByPublisherMatch() {
        webtest('出版社を条件に書籍を検索。マッチする書籍が 2 冊あり。') {
            invoke(url: 'order')
            setInputField(name: 'publisher', value: '翔泳社')
            clickButton(label: '検索')
            verifyText(text: 'オブジェクト指向入門 第 2 版 原則・コンセプト')
            verifyText(text: 'UML モデリングのエッセンス 第 3 版 標準オブジェクトモデリング言語入門')
        }
    }

    void testSearchByPublisherNoMatch() {
        webtest('出版社を条件に書籍を検索。マッチする書籍はなし。') {
            invoke(url: 'order')
            setInputField(name: 'publisher', value: '翔英社')
            clickButton(label: '検索')
            verifyText(text: '検索条件に合う書籍は見つかりませんでした。')
        }
    }

    void testSearchByTitleAndAuthorAndIsbn13AndPublisherMatch() {
        webtest('タイトルと著者と ISBN13 と出版社を条件に書籍を検索。マッチする書籍が 1 冊あり。') {
            invoke(url: 'order')
            setInputField(name: 'title', value: 'エッセンス')
            setInputField(name: 'author', value: 'Fowler')
            setInputField(name: 'isbn13', value: '9784798107950')
            setInputField(name: 'publisher', value: '翔泳社')
            clickButton(label: '検索')
            verifyText(text: 'UML モデリングのエッセンス 第 3 版 標準オブジェクトモデリング言語入門')
        }
    }

    void testSearchByTitleAndAuthorAndIsbn13AndPublisherNoMatch() {
        webtest('タイトルと著者と ISBN13 と出版社を条件に書籍を検索。マッチする書籍はなし。') {
            invoke(url: 'order')
            setInputField(name: 'title', value: 'エッセンス')
            setInputField(name: 'author', value: 'Fowler')
            setInputField(name: 'isbn13', value: '9784798107951')
            setInputField(name: 'publisher', value: '翔泳社')
            clickButton(label: '検索')
            verifyText(text: '検索条件に合う書籍は見つかりませんでした。')
        }
    }

    // 検索画面で「詳細」
    void testSearchFlowSearchToDetail() {
        webtest('検索画面で「詳細」') {
            invoke(url: 'order')
            setInputField(name: 'title', value: 'オブジェクト指向入門')
            clickButton(label: '検索')
            clickLink(label: '詳細')
            verifyText(text: 'オブジェクト指向入門 第 2 版 原則・コンセプト')
        }
    }

    // 検索画面で「カートに入れる」
    void testSearchFlowSearchToToCart() {
        webtest('検索画面で「カートに入れる」') {
            invoke(url: 'order')
            setInputField(name: 'title', value: 'オブジェクト指向入門')
            clickButton(label: '検索')
            verifyText(text: 'オブジェクト指向入門 第 2 版 原則・コンセプト')
            clickLink(label: 'カートに入れる')
            verifyText(text: 'カートに追加しました。')
        }
    }

    // 詳細画面で「検索画面に戻る」
    void testSearchFlowDisplayDetailToSearch() {
        webtest('詳細画面で「検索画面に戻る」') {
            invoke(url: 'order')
            setInputField(name: 'title', value: 'オブジェクト指向入門')
            clickButton(label: '検索')
            clickLink(label: '詳細')
            verifyText(text: 'オブジェクト指向入門 第 2 版 原則・コンセプト')
            clickButton(label: '検索画面に戻る')
            verifyText(text: 'オブジェクト指向入門 第 2 版 原則・コンセプト')
        }
    }

    void testSearchFlowDisplayDetailToToCart() {
        webtest('詳細画面で「カートに入れる」') {
            invoke(url: 'order')
            setInputField(name: 'title', value: 'エッセンス')
            clickButton(label: '検索')
            verifyText(text: 'UML モデリングのエッセンス 第 3 版 標準オブジェクトモデリング言語入門')
            clickLink(label: '詳細')
            verifyText(text: 'UML モデリングのエッセンス 第 3 版 標準オブジェクトモデリング言語入門')
            clickButton(label: 'カートに入れる')
            verifyText(text: 'カートに追加しました。')
        }
    }

    void testSearchFlowDisplayDetailToToCartTwice() {
        webtest('詳細画面で「カートに入れる」。同じ書籍を 2 冊。') {
            invoke(url: 'order')
            setInputField(name: 'title', value: 'エッセンス')
            clickButton(label: '検索')
            verifyText(text: 'UML モデリングのエッセンス 第 3 版 標準オブジェクトモデリング言語入門')
            clickLink(label: '詳細')
            verifyText(text: 'UML モデリングのエッセンス 第 3 版 標準オブジェクトモデリング言語入門')
            clickButton(label: 'カートに入れる')
            verifyText(text: 'カートに追加しました。')
            clickButton(label: 'カートに入れる')
            verifyText(text: 'カートに追加しました。')
        }
    }

    // 詳細画面で「カートに入れる」
    void testSearchFlowDisplayDetailToToCartTwo() {
        webtest('詳細画面で「カートに入れる」。異なる書籍を 1 冊ずつ。') {
            invoke(url: 'order')
            setInputField(name: 'title', value: 'エッセンス')
            clickButton(label: '検索')
            verifyText(text: 'UML モデリングのエッセンス 第 3 版 標準オブジェクトモデリング言語入門')
            clickLink(label: '詳細')
            verifyText(text: 'UML モデリングのエッセンス 第 3 版 標準オブジェクトモデリング言語入門')
            clickButton(label: 'カートに入れる')
            verifyText(text: 'カートに追加しました。')
            clickButton(label: '検索画面に戻る')
            setInputField(name: 'title', value: 'オブジェクト指向入門')
            clickButton(label: '検索')
            verifyText(text: 'オブジェクト指向入門 第 2 版 原則・コンセプト')
            clickLink(label: '詳細')
            verifyText(text: 'オブジェクト指向入門 第 2 版 原則・コンセプト')
            clickButton(label: 'カートに入れる')
            verifyText(text: 'カートに追加しました。')
        }
    }

    void testGoCart() {
        webtest('メニューから「カートを見る」') {
            invoke(url: 'order')

            group(description:'カートに書籍を入れる') {
                setInputField(name: 'title', value: 'オブジェクト指向入門')
                clickButton(label: '検索')
                verifyText(text: 'オブジェクト指向入門 第 2 版 原則・コンセプト')
                clickLink(label: '詳細')
                verifyText(text: 'オブジェクト指向入門 第 2 版 原則・コンセプト')
                clickButton(label: 'カートに入れる')
                verifyText(text: 'カートに追加しました。')
                clickButton(label: '検索画面に戻る')
                setInputField(name: 'title', value: 'エッセンス')
                clickButton(label: '検索')
                verifyText(text: 'UML モデリングのエッセンス 第 3 版 標準オブジェクトモデリング言語入門')
                clickLink(label: '詳細')
                verifyText(text: 'UML モデリングのエッセンス 第 3 版 標準オブジェクトモデリング言語入門')
                clickButton(label: 'カートに入れる')
                verifyText(text: 'カートに追加しました。')
            }

            clickLink(label: 'カートを見る')
            verifyText(text: 'オブジェクト指向入門 第 2 版 原則・コンセプト')
            verifyText(text: 'UML モデリングのエッセンス 第 3 版 標準オブジェクトモデリング言語入門')
            verifyXPath(xpath: "//span[@id='quantity\$1']", text: '1')
            verifyXPath(xpath: "//span[@id='quantity\$2']", text: '1')
        }
    }

    void testCartFlowShowCartToEditCart() {
        webtest('カート内容画面で「カートの中を編集」') {
            invoke(url: 'order')

            group(description:'カートに書籍を入れる') {
                setInputField(name: 'title', value: 'オブジェクト指向入門')
                clickButton(label: '検索')
                verifyText(text: 'オブジェクト指向入門 第 2 版 原則・コンセプト')
                clickLink(label: '詳細')
                verifyText(text: 'オブジェクト指向入門 第 2 版 原則・コンセプト')
                clickButton(label: 'カートに入れる')
                verifyText(text: 'カートに追加しました。')
                clickButton(label: '検索画面に戻る')
                setInputField(name: 'title', value: 'エッセンス')
                clickButton(label: '検索')
                verifyText(text: 'UML モデリングのエッセンス 第 3 版 標準オブジェクトモデリング言語入門')
                clickLink(label: '詳細')
                verifyText(text: 'UML モデリングのエッセンス 第 3 版 標準オブジェクトモデリング言語入門')
                clickButton(label: 'カートに入れる')
                verifyText(text: 'カートに追加しました。')
            }

            group(description:'カートを見る') {
                clickLink(label: 'カートを見る')
                verifyText(text: 'オブジェクト指向入門 第 2 版 原則・コンセプト')
                verifyText(text: 'UML モデリングのエッセンス 第 3 版 標準オブジェクトモデリング言語入門')
                verifyXPath(xpath: "//span[@id='quantity\$1']", text: '1')
                verifyXPath(xpath: "//span[@id='quantity\$2']", text: '1')
            }

            clickButton(label: 'カートの中を編集する')
            verifyText(text: 'オブジェクト指向入門 第 2 版 原則・コンセプト')
            verifyText(text: 'UML モデリングのエッセンス 第 3 版 標準オブジェクトモデリング言語入門')
            verifyInputField(name: 'quantity$1', value: '1')
            verifyInputField(name: 'quantity$2', value: '1')
        }
    }

    void testCartFlowEditCartToSubmit() {
        webtest('カート内容編集画面で「編集」') {
            invoke(url: 'order')

            group(description:'カートに書籍を入れる') {
                setInputField(name: 'title', value: 'オブジェクト指向入門')
                clickButton(label: '検索')
                verifyText(text: 'オブジェクト指向入門 第 2 版 原則・コンセプト')
                clickLink(label: '詳細')
                verifyText(text: 'オブジェクト指向入門 第 2 版 原則・コンセプト')
                clickButton(label: 'カートに入れる')
                verifyText(text: 'カートに追加しました。')
                clickButton(label: '検索画面に戻る')
                setInputField(name: 'title', value: 'エッセンス')
                clickButton(label: '検索')
                verifyText(text: 'UML モデリングのエッセンス 第 3 版 標準オブジェクトモデリング言語入門')
                clickLink(label: '詳細')
                verifyText(text: 'UML モデリングのエッセンス 第 3 版 標準オブジェクトモデリング言語入門')
                clickButton(label: 'カートに入れる')
                verifyText(text: 'カートに追加しました。')
            }

            clickLink(label: 'カートを見る')
            verifyText(text: 'オブジェクト指向入門 第 2 版 原則・コンセプト')
            verifyText(text: 'UML モデリングのエッセンス 第 3 版 標準オブジェクトモデリング言語入門')
            verifyXPath(xpath: "//span[@id='quantity\$1']", text: '1')
            verifyXPath(xpath: "//span[@id='quantity\$2']", text: '1')
            clickButton(label: 'カートの中を編集する')
            verifyText(text: 'オブジェクト指向入門 第 2 版 原則・コンセプト')
            verifyText(text: 'UML モデリングのエッセンス 第 3 版 標準オブジェクトモデリング言語入門')
            setInputField(name: 'quantity$1', value: '2')
            setInputField(name: 'quantity$2', value: '3')
            clickButton(label: '編集')
            verifyXPath(xpath: "//span[@id='quantity\$1']", text: '2')
            verifyXPath(xpath: "//span[@id='quantity\$2']", text: '3')
        }
    }

    void testCartFlowEditCartToSubmitOther0() {
        webtest('カート内容編集画面で「編集」。2 種類のうち片方だけ 0 冊に。') {
            invoke(url: 'order')

            group(description:'カートに書籍を入れる') {
                setInputField(name: 'title', value: 'オブジェクト指向入門')
                clickButton(label: '検索')
                verifyText(text: 'オブジェクト指向入門 第 2 版 原則・コンセプト')
                clickLink(label: '詳細')
                verifyText(text: 'オブジェクト指向入門 第 2 版 原則・コンセプト')
                clickButton(label: 'カートに入れる')
                verifyText(text: 'カートに追加しました。')
                clickButton(label: '検索画面に戻る')
                setInputField(name: 'title', value: 'エッセンス')
                clickButton(label: '検索')
                verifyText(text: 'UML モデリングのエッセンス 第 3 版 標準オブジェクトモデリング言語入門')
                clickLink(label: '詳細')
                verifyText(text: 'UML モデリングのエッセンス 第 3 版 標準オブジェクトモデリング言語入門')
                clickButton(label: 'カートに入れる')
                verifyText(text: 'カートに追加しました。')
            }

            clickLink(label: 'カートを見る')
            verifyText(text: 'オブジェクト指向入門 第 2 版 原則・コンセプト')
            verifyText(text: 'UML モデリングのエッセンス 第 3 版 標準オブジェクトモデリング言語入門')
            verifyXPath(xpath: "//span[@id='quantity\$1']", text: '1')
            verifyXPath(xpath: "//span[@id='quantity\$2']", text: '1')
            clickButton(label: 'カートの中を編集する')
            verifyText(text: 'オブジェクト指向入門 第 2 版 原則・コンセプト')
            verifyText(text: 'UML モデリングのエッセンス 第 3 版 標準オブジェクトモデリング言語入門')
            setInputField(name: 'quantity$1', value: '0')
            setInputField(name: 'quantity$2', value: '3')
            clickButton(label: '編集')
            verifyText(text: 'UML モデリングのエッセンス 第 3 版 標準オブジェクトモデリング言語入門')
            verifyXPath(xpath: "//span[@id='quantity\$2']", text: '3')
        }
    }

    void testCartFlowEditCartToCancel() {
        webtest('カート内容編集画面で「キャンセル」') {
            invoke(url: 'order')

            group(description:'カートに書籍を入れる') {
                setInputField(name: 'title', value: 'オブジェクト指向入門')
                clickButton(label: '検索')
                verifyText(text: 'オブジェクト指向入門 第 2 版 原則・コンセプト')
                clickLink(label: '詳細')
                verifyText(text: 'オブジェクト指向入門 第 2 版 原則・コンセプト')
                clickButton(label: 'カートに入れる')
                verifyText(text: 'カートに追加しました。')
                clickButton(label: '検索画面に戻る')
                setInputField(name: 'title', value: 'エッセンス')
                clickButton(label: '検索')
                verifyText(text: 'UML モデリングのエッセンス 第 3 版 標準オブジェクトモデリング言語入門')
                clickLink(label: '詳細')
                verifyText(text: 'UML モデリングのエッセンス 第 3 版 標準オブジェクトモデリング言語入門')
                clickButton(label: 'カートに入れる')
                verifyText(text: 'カートに追加しました。')
            }

            clickLink(label: 'カートを見る')
            verifyText(text: 'オブジェクト指向入門 第 2 版 原則・コンセプト')
            verifyText(text: 'UML モデリングのエッセンス 第 3 版 標準オブジェクトモデリング言語入門')
            verifyXPath(xpath: "//span[@id='quantity\$1']", text: '1')
            verifyXPath(xpath: "//span[@id='quantity\$2']", text: '1')
            clickButton(label: 'カートの中を編集する')
            verifyText(text: 'オブジェクト指向入門 第 2 版 原則・コンセプト')
            verifyText(text: 'UML モデリングのエッセンス 第 3 版 標準オブジェクトモデリング言語入門')
            setInputField(name: 'quantity$1', value: '2')
            setInputField(name: 'quantity$2', value: '3')
            clickButton(label: 'キャンセル')
            verifyXPath(xpath: "//span[@id='quantity\$1']", text: '1')
            verifyXPath(xpath: "//span[@id='quantity\$2']", text: '1')
        }
    }

    void testCartFlowShowCartToCreditCartConfirm() {
        webtest('カート内容画面で「精算」') {
            invoke(url: 'order')

            group(description:'カートに書籍を入れる') {
                setInputField(name: 'title', value: 'オブジェクト指向入門')
                clickButton(label: '検索')
                verifyText(text: 'オブジェクト指向入門 第 2 版 原則・コンセプト')
                clickLink(label: '詳細')
                verifyText(text: 'オブジェクト指向入門 第 2 版 原則・コンセプト')
                clickButton(label: 'カートに入れる')
                verifyText(text: 'カートに追加しました。')
                clickButton(label: '検索画面に戻る')
                setInputField(name: 'title', value: 'エッセンス')
                clickButton(label: '検索')
                verifyText(text: 'UML モデリングのエッセンス 第 3 版 標準オブジェクトモデリング言語入門')
                clickLink(label: '詳細')
                verifyText(text: 'UML モデリングのエッセンス 第 3 版 標準オブジェクトモデリング言語入門')
                clickButton(label: 'カートに入れる')
                verifyText(text: 'カートに追加しました。')
            }

            clickLink(label: 'カートを見る')
            verifyText(text: 'オブジェクト指向入門 第 2 版 原則・コンセプト')
            verifyText(text: 'UML モデリングのエッセンス 第 3 版 標準オブジェクトモデリング言語入門')
            verifyXPath(xpath: "//span[@id='quantity\$1']", text: '1')
            verifyXPath(xpath: "//span[@id='quantity\$2']", text: '1')
            clickButton(label: '精算')
            verifyXPath(xpath: "//span[@id='title\$1']", text: 'オブジェクト指向入門 第 2 版 原則・コンセプト')
            verifyXPath(xpath: "//span[@id='price\$1']", text: '7560')
            verifyXPath(xpath: "//span[@id='quantity\$1']", text: '1')
            verifyXPath(xpath: "//span[@id='subTotal\$1']", text: '7560')
            verifyXPath(xpath: "//span[@id='title\$2']", text: 'UML モデリングのエッセンス 第 3 版 標準オブジェクトモデリング言語入門')
            verifyXPath(xpath: "//span[@id='price\$2']", text: '2520')
            verifyXPath(xpath: "//span[@id='quantity\$2']", text: '1')
            verifyXPath(xpath: "//span[@id='subTotal\$2']", text: '2520')
            verifyXPath(xpath: "//span[@id='totalPrice']", text: '10080')
        }
    }

    void testCreditFlowCreditToNext() {
        webtest('カート内容確認画面で「次へ」') {
            invoke(url: 'order')

            group(description:'カートに書籍を入れる') {
                setInputField(name: 'title', value: 'オブジェクト指向入門')
                clickButton(label: '検索')
                verifyText(text: 'オブジェクト指向入門 第 2 版 原則・コンセプト')
                clickLink(label: '詳細')
                verifyText(text: 'オブジェクト指向入門 第 2 版 原則・コンセプト')
                clickButton(label: 'カートに入れる')
                verifyText(text: 'カートに追加しました。')
                clickButton(label: '検索画面に戻る')
                setInputField(name: 'title', value: 'エッセンス')
                clickButton(label: '検索')
                verifyText(text: 'UML モデリングのエッセンス 第 3 版 標準オブジェクトモデリング言語入門')
                clickLink(label: '詳細')
                verifyText(text: 'UML モデリングのエッセンス 第 3 版 標準オブジェクトモデリング言語入門')
                clickButton(label: 'カートに入れる')
                verifyText(text: 'カートに追加しました。')
            }

            clickLink(label: 'カートを見る')
            verifyText(text: 'オブジェクト指向入門 第 2 版 原則・コンセプト')
            verifyText(text: 'UML モデリングのエッセンス 第 3 版 標準オブジェクトモデリング言語入門')
            verifyXPath(xpath: "//span[@id='quantity\$1']", text: '1')
            verifyXPath(xpath: "//span[@id='quantity\$2']", text: '1')
            clickButton(label: '精算')
            verifyXPath(xpath: "//span[@id='title\$1']", text: 'オブジェクト指向入門 第 2 版 原則・コンセプト')
            verifyXPath(xpath: "//span[@id='price\$1']", text: '7560')
            verifyXPath(xpath: "//span[@id='quantity\$1']", text: '1')
            verifyXPath(xpath: "//span[@id='subTotal\$1']", text: '7560')
            verifyXPath(xpath: "//span[@id='title\$2']", text: 'UML モデリングのエッセンス 第 3 版 標準オブジェクトモデリング言語入門')
            verifyXPath(xpath: "//span[@id='price\$2']", text: '2520')
            verifyXPath(xpath: "//span[@id='quantity\$2']", text: '1')
            verifyXPath(xpath: "//span[@id='subTotal\$2']", text: '2520')
            verifyXPath(xpath: "//span[@id='totalPrice']", text: '10080')
            clickButton(label: '次へ')
        }
    }

    void testCreditFlowCreditAccountConfirmToNext() {
        webtest('支払情報確認画面で「次へ」') {
            invoke(url: 'order')

            group(description:'カートに書籍を入れる') {
                setInputField(name: 'title', value: 'オブジェクト指向入門')
                clickButton(label: '検索')
                verifyText(text: 'オブジェクト指向入門 第 2 版 原則・コンセプト')
                clickLink(label: '詳細')
                verifyText(text: 'オブジェクト指向入門 第 2 版 原則・コンセプト')
                clickButton(label: 'カートに入れる')
                verifyText(text: 'カートに追加しました。')
                clickButton(label: '検索画面に戻る')
                setInputField(name: 'title', value: 'エッセンス')
                clickButton(label: '検索')
                verifyText(text: 'UML モデリングのエッセンス 第 3 版 標準オブジェクトモデリング言語入門')
                clickLink(label: '詳細')
                verifyText(text: 'UML モデリングのエッセンス 第 3 版 標準オブジェクトモデリング言語入門')
                clickButton(label: 'カートに入れる')
                verifyText(text: 'カートに追加しました。')
            }

            clickLink(label: 'カートを見る')
            verifyText(text: 'オブジェクト指向入門 第 2 版 原則・コンセプト')
            verifyText(text: 'UML モデリングのエッセンス 第 3 版 標準オブジェクトモデリング言語入門')
            verifyXPath(xpath: "//span[@id='quantity\$1']", text: '1')
            verifyXPath(xpath: "//span[@id='quantity\$2']", text: '1')
            clickButton(label: '精算')
            verifyXPath(xpath: "//span[@id='title\$1']", text: 'オブジェクト指向入門 第 2 版 原則・コンセプト')
            verifyXPath(xpath: "//span[@id='price\$1']", text: '7560')
            verifyXPath(xpath: "//span[@id='quantity\$1']", text: '1')
            verifyXPath(xpath: "//span[@id='subTotal\$1']", text: '7560')
            verifyXPath(xpath: "//span[@id='title\$2']", text: 'UML モデリングのエッセンス 第 3 版 標準オブジェクトモデリング言語入門')
            verifyXPath(xpath: "//span[@id='price\$2']", text: '2520')
            verifyXPath(xpath: "//span[@id='quantity\$2']", text: '1')
            verifyXPath(xpath: "//span[@id='subTotal\$2']", text: '2520')
            verifyXPath(xpath: "//span[@id='totalPrice']", text: '10080')
            clickButton(label: '次へ')
            setInputField(name: 'name', value: '山田太郎')
            setInputField(name: 'address', value: '東京都港区六本木')
            setInputField(name: 'phoneNumber', value: '03-1234-5678')
            setInputField(name: 'email', value: 'yamada.taro@email.jp')
            setInputField(name: 'paymentMethod', value: '代金引換')
            clickButton(label: '次へ')
            verifyXPath(xpath: "//span[@id='title\$1']", text: 'オブジェクト指向入門 第 2 版 原則・コンセプト')
            verifyXPath(xpath: "//span[@id='price\$1']", text: '7560')
            verifyXPath(xpath: "//span[@id='quantity\$1']", text: '1')
            verifyXPath(xpath: "//span[@id='title\$2']", text: 'UML モデリングのエッセンス 第 3 版 標準オブジェクトモデリング言語入門')
            verifyXPath(xpath: "//span[@id='price\$2']", text: '2520')
            verifyXPath(xpath: "//span[@id='quantity\$2']", text: '1')
            verifyXPath(xpath: "//span[@id='totalPrice']", text: '10080')
            verifyXPath(xpath: "//span[@id='name']", text: '山田太郎')
            verifyXPath(xpath: "//span[@id='address']", text: '東京都港区六本木')
            verifyXPath(xpath: "//span[@id='phoneNumber']", text: '03-1234-5678')
            verifyXPath(xpath: "//span[@id='email']", text: 'yamada.taro@email.jp')
            verifyXPath(xpath: "//span[@id='paymentMethod']", text: '代金引換')
        }
    }

    void testCreditFlowCreditAccountConfirmToBack() {
        webtest('支払情報確認画面で「戻る」') {
            invoke(url: 'order')

            group(description:'カートに書籍を入れる') {
                setInputField(name: 'title', value: 'オブジェクト指向入門')
                clickButton(label: '検索')
                verifyText(text: 'オブジェクト指向入門 第 2 版 原則・コンセプト')
                clickLink(label: '詳細')
                verifyText(text: 'オブジェクト指向入門 第 2 版 原則・コンセプト')
                clickButton(label: 'カートに入れる')
                verifyText(text: 'カートに追加しました。')
                clickButton(label: '検索画面に戻る')
                setInputField(name: 'title', value: 'エッセンス')
                clickButton(label: '検索')
                verifyText(text: 'UML モデリングのエッセンス 第 3 版 標準オブジェクトモデリング言語入門')
                clickLink(label: '詳細')
                verifyText(text: 'UML モデリングのエッセンス 第 3 版 標準オブジェクトモデリング言語入門')
                clickButton(label: 'カートに入れる')
                verifyText(text: 'カートに追加しました。')
            }

            clickLink(label: 'カートを見る')
            verifyText(text: 'オブジェクト指向入門 第 2 版 原則・コンセプト')
            verifyText(text: 'UML モデリングのエッセンス 第 3 版 標準オブジェクトモデリング言語入門')
            verifyXPath(xpath: "//span[@id='quantity\$1']", text: '1')
            verifyXPath(xpath: "//span[@id='quantity\$2']", text: '1')
            clickButton(label: '精算')
            verifyXPath(xpath: "//span[@id='title\$1']", text: 'オブジェクト指向入門 第 2 版 原則・コンセプト')
            verifyXPath(xpath: "//span[@id='price\$1']", text: '7560')
            verifyXPath(xpath: "//span[@id='quantity\$1']", text: '1')
            verifyXPath(xpath: "//span[@id='subTotal\$1']", text: '7560')
            verifyXPath(xpath: "//span[@id='title\$2']", text: 'UML モデリングのエッセンス 第 3 版 標準オブジェクトモデリング言語入門')
            verifyXPath(xpath: "//span[@id='price\$2']", text: '2520')
            verifyXPath(xpath: "//span[@id='quantity\$2']", text: '1')
            verifyXPath(xpath: "//span[@id='subTotal\$2']", text: '2520')
            verifyXPath(xpath: "//span[@id='totalPrice']", text: '10080')
            clickButton(label: '次へ')
            setInputField(name: 'name', value: '山田太郎')
            setInputField(name: 'address', value: '東京都港区六本木')
            setInputField(name: 'phoneNumber', value: '03-1234-5678')
            setInputField(name: 'email', value: 'yamada.taro@email.jp')
            setInputField(name: 'paymentMethod', value: '代金引換')
            clickButton(label: '戻る')
        }
    }

    void testCreditFlowCreditFinalConfirmToNext() {
        webtest('最終確認画面で「精算」') {
            invoke(url: 'order')

            group(description:'カートに書籍を入れる') {
                setInputField(name: 'title', value: 'オブジェクト指向入門')
                clickButton(label: '検索')
                verifyText(text: 'オブジェクト指向入門 第 2 版 原則・コンセプト')
                clickLink(label: '詳細')
                verifyText(text: 'オブジェクト指向入門 第 2 版 原則・コンセプト')
                clickButton(label: 'カートに入れる')
                verifyText(text: 'カートに追加しました。')
                clickButton(label: '検索画面に戻る')
                setInputField(name: 'title', value: 'エッセンス')
                clickButton(label: '検索')
                verifyText(text: 'UML モデリングのエッセンス 第 3 版 標準オブジェクトモデリング言語入門')
                clickLink(label: '詳細')
                verifyText(text: 'UML モデリングのエッセンス 第 3 版 標準オブジェクトモデリング言語入門')
                clickButton(label: 'カートに入れる')
                verifyText(text: 'カートに追加しました。')
            }

            clickLink(label: 'カートを見る')
            verifyText(text: 'オブジェクト指向入門 第 2 版 原則・コンセプト')
            verifyText(text: 'UML モデリングのエッセンス 第 3 版 標準オブジェクトモデリング言語入門')
            verifyXPath(xpath: "//span[@id='quantity\$1']", text: '1')
            verifyXPath(xpath: "//span[@id='quantity\$2']", text: '1')
            clickButton(label: '精算')
            verifyXPath(xpath: "//span[@id='title\$1']", text: 'オブジェクト指向入門 第 2 版 原則・コンセプト')
            verifyXPath(xpath: "//span[@id='price\$1']", text: '7560')
            verifyXPath(xpath: "//span[@id='quantity\$1']", text: '1')
            verifyXPath(xpath: "//span[@id='subTotal\$1']", text: '7560')
            verifyXPath(xpath: "//span[@id='title\$2']", text: 'UML モデリングのエッセンス 第 3 版 標準オブジェクトモデリング言語入門')
            verifyXPath(xpath: "//span[@id='price\$2']", text: '2520')
            verifyXPath(xpath: "//span[@id='quantity\$2']", text: '1')
            verifyXPath(xpath: "//span[@id='subTotal\$2']", text: '2520')
            verifyXPath(xpath: "//span[@id='totalPrice']", text: '10080')
            clickButton(label: '次へ')
            setInputField(name: 'name', value: '山田太郎')
            setInputField(name: 'address', value: '東京都港区六本木')
            setInputField(name: 'phoneNumber', value: '03-1234-5678')
            setInputField(name: 'email', value: 'yamada.taro@email.jp')
            setInputField(name: 'paymentMethod', value: '代金引換')
            clickButton(label: '次へ')
            verifyXPath(xpath: "//span[@id='title\$1']", text: 'オブジェクト指向入門 第 2 版 原則・コンセプト')
            verifyXPath(xpath: "//span[@id='price\$1']", text: '7560')
            verifyXPath(xpath: "//span[@id='quantity\$1']", text: '1')
            verifyXPath(xpath: "//span[@id='subTotal\$1']", text: '7560')
            verifyXPath(xpath: "//span[@id='title\$2']", text: 'UML モデリングのエッセンス 第 3 版 標準オブジェクトモデリング言語入門')
            verifyXPath(xpath: "//span[@id='price\$2']", text: '2520')
            verifyXPath(xpath: "//span[@id='quantity\$2']", text: '1')
            verifyXPath(xpath: "//span[@id='subTotal\$2']", text: '2520')
            verifyXPath(xpath: "//span[@id='totalPrice']", text: '10080')
            verifyXPath(xpath: "//span[@id='name']", text: '山田太郎')
            verifyXPath(xpath: "//span[@id='address']", text: '東京都港区六本木')
            verifyXPath(xpath: "//span[@id='phoneNumber']", text: '03-1234-5678')
            verifyXPath(xpath: "//span[@id='email']", text: 'yamada.taro@email.jp')
            verifyXPath(xpath: "//span[@id='paymentMethod']", text: '代金引換')
            clickButton(label: '精算')
        }
    }

    void testCreditFlowCreditFinalConfirmToBack() {
        webtest('最終確認画面で「戻る」') {
            invoke(url: 'order')

            group(description:'カートに書籍を入れる') {
                setInputField(name: 'title', value: 'オブジェクト指向入門')
                clickButton(label: '検索')
                verifyText(text: 'オブジェクト指向入門 第 2 版 原則・コンセプト')
                clickLink(label: '詳細')
                verifyText(text: 'オブジェクト指向入門 第 2 版 原則・コンセプト')
                clickButton(label: 'カートに入れる')
                verifyText(text: 'カートに追加しました。')
                clickButton(label: '検索画面に戻る')
                setInputField(name: 'title', value: 'エッセンス')
                clickButton(label: '検索')
                verifyText(text: 'UML モデリングのエッセンス 第 3 版 標準オブジェクトモデリング言語入門')
                clickLink(label: '詳細')
                verifyText(text: 'UML モデリングのエッセンス 第 3 版 標準オブジェクトモデリング言語入門')
                clickButton(label: 'カートに入れる')
                verifyText(text: 'カートに追加しました。')
            }

            clickLink(label: 'カートを見る')
            verifyText(text: 'オブジェクト指向入門 第 2 版 原則・コンセプト')
            verifyText(text: 'UML モデリングのエッセンス 第 3 版 標準オブジェクトモデリング言語入門')
            verifyXPath(xpath: "//span[@id='quantity\$1']", text: '1')
            verifyXPath(xpath: "//span[@id='quantity\$2']", text: '1')
            clickButton(label: '精算')
            verifyXPath(xpath: "//span[@id='title\$1']", text: 'オブジェクト指向入門 第 2 版 原則・コンセプト')
            verifyXPath(xpath: "//span[@id='price\$1']", text: '7560')
            verifyXPath(xpath: "//span[@id='quantity\$1']", text: '1')
            verifyXPath(xpath: "//span[@id='title\$2']", text: 'UML モデリングのエッセンス 第 3 版 標準オブジェクトモデリング言語入門')
            verifyXPath(xpath: "//span[@id='price\$2']", text: '2520')
            verifyXPath(xpath: "//span[@id='quantity\$2']", text: '1')
            verifyXPath(xpath: "//span[@id='totalPrice']", text: '10080')
            clickButton(label: '次へ')
            setInputField(name: 'name', value: '山田太郎')
            setInputField(name: 'address', value: '東京都港区六本木')
            setInputField(name: 'phoneNumber', value: '03-1234-5678')
            setInputField(name: 'email', value: 'yamada.taro@email.jp')
            setInputField(name: 'paymentMethod', value: '代金引換')
            clickButton(label: '次へ')
            verifyXPath(xpath: "//span[@id='title\$1']", text: 'オブジェクト指向入門 第 2 版 原則・コンセプト')
            verifyXPath(xpath: "//span[@id='price\$1']", text: '7560')
            verifyXPath(xpath: "//span[@id='quantity\$1']", text: '1')
            verifyXPath(xpath: "//span[@id='title\$2']", text: 'UML モデリングのエッセンス 第 3 版 標準オブジェクトモデリング言語入門')
            verifyXPath(xpath: "//span[@id='price\$2']", text: '2520')
            verifyXPath(xpath: "//span[@id='quantity\$2']", text: '1')
            verifyXPath(xpath: "//span[@id='totalPrice']", text: '10080')
            verifyXPath(xpath: "//span[@id='name']", text: '山田太郎')
            verifyXPath(xpath: "//span[@id='address']", text: '東京都港区六本木')
            verifyXPath(xpath: "//span[@id='phoneNumber']", text: '03-1234-5678')
            verifyXPath(xpath: "//span[@id='email']", text: 'yamada.taro@email.jp')
            verifyXPath(xpath: "//span[@id='paymentMethod']", text: '代金引換')
            clickButton(label: '戻る')
        }
    }

    void testCreditFlowCreditCompleteToFinish() {
        webtest('精算完了画面で「戻る」') {
            invoke(url: 'order')

            group(description:'カートに書籍を入れる') {
                setInputField(name: 'title', value: 'オブジェクト指向入門')
                clickButton(label: '検索')
                verifyText(text: 'オブジェクト指向入門 第 2 版 原則・コンセプト')
                clickLink(label: '詳細')
                verifyText(text: 'オブジェクト指向入門 第 2 版 原則・コンセプト')
                clickButton(label: 'カートに入れる')
                verifyText(text: 'カートに追加しました。')
                clickButton(label: '検索画面に戻る')
                setInputField(name: 'title', value: 'エッセンス')
                clickButton(label: '検索')
                verifyText(text: 'UML モデリングのエッセンス 第 3 版 標準オブジェクトモデリング言語入門')
                clickLink(label: '詳細')
                verifyText(text: 'UML モデリングのエッセンス 第 3 版 標準オブジェクトモデリング言語入門')
                clickButton(label: 'カートに入れる')
                verifyText(text: 'カートに追加しました。')
            }

            clickLink(label: 'カートを見る')
            verifyText(text: 'オブジェクト指向入門 第 2 版 原則・コンセプト')
            verifyText(text: 'UML モデリングのエッセンス 第 3 版 標準オブジェクトモデリング言語入門')
            verifyXPath(xpath: "//span[@id='quantity\$1']", text: '1')
            verifyXPath(xpath: "//span[@id='quantity\$2']", text: '1')
            clickButton(label: '精算')
            verifyXPath(xpath: "//span[@id='title\$1']", text: 'オブジェクト指向入門 第 2 版 原則・コンセプト')
            verifyXPath(xpath: "//span[@id='price\$1']", text: '7560')
            verifyXPath(xpath: "//span[@id='quantity\$1']", text: '1')
            verifyXPath(xpath: "//span[@id='title\$2']", text: 'UML モデリングのエッセンス 第 3 版 標準オブジェクトモデリング言語入門')
            verifyXPath(xpath: "//span[@id='price\$2']", text: '2520')
            verifyXPath(xpath: "//span[@id='quantity\$2']", text: '1')
            verifyXPath(xpath: "//span[@id='totalPrice']", text: '10080')
            clickButton(label: '次へ')
            setInputField(name: 'name', value: '山田太郎')
            setInputField(name: 'address', value: '東京都港区六本木')
            setInputField(name: 'phoneNumber', value: '03-1234-5678')
            setInputField(name: 'email', value: 'yamada.taro@email.jp')
            setInputField(name: 'paymentMethod', value: '代金引換')
            clickButton(label: '次へ')
            verifyXPath(xpath: "//span[@id='title\$1']", text: 'オブジェクト指向入門 第 2 版 原則・コンセプト')
            verifyXPath(xpath: "//span[@id='price\$1']", text: '7560')
            verifyXPath(xpath: "//span[@id='quantity\$1']", text: '1')
            verifyXPath(xpath: "//span[@id='title\$2']", text: 'UML モデリングのエッセンス 第 3 版 標準オブジェクトモデリング言語入門')
            verifyXPath(xpath: "//span[@id='price\$2']", text: '2520')
            verifyXPath(xpath: "//span[@id='quantity\$2']", text: '1')
            verifyXPath(xpath: "//span[@id='totalPrice']", text: '10080')
            verifyXPath(xpath: "//span[@id='name']", text: '山田太郎')
            verifyXPath(xpath: "//span[@id='address']", text: '東京都港区六本木')
            verifyXPath(xpath: "//span[@id='phoneNumber']", text: '03-1234-5678')
            verifyXPath(xpath: "//span[@id='email']", text: 'yamada.taro@email.jp')
            verifyXPath(xpath: "//span[@id='paymentMethod']", text: '代金引換')
            clickButton(label: '精算')
            clickButton(label: '完了')
        }
    }
}
